.. _fluent_pages.pagetypes.fluentpage.admin:

fluent_pages.pagetypes.fluentpage.admin
=======================================

.. automodule:: fluent_pages.pagetypes.fluentpage.admin

The ``FluentPageAdmin`` class
-----------------------------

.. autoclass:: fluent_pages.pagetypes.fluentpage.admin.FluentPageAdmin
   :members:
